Documentation
¶
Index ¶
- func GetAccountFromNamespace(namespace metav1.Object) string
- func InformerForResource(mgr manager.Manager, gvr schema.GroupVersionResource) (ctrlcache.Informer, error)
- func IsNamespaceInitializing(namespace metav1.Object) bool
- func ListerFuncForResourceFunc(mgr manager.Manager) quota.ListerForResourceFunc
- func Output(command string, args ...string) (string, error)
- func Run(command string, args ...string) error
- func StringsEqual(a []string, b []string) bool
- type LockFactory
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAccountFromNamespace ¶
GetAccountFromNamespace retrieves the account from a namespace meta
func InformerForResource ¶
func InformerForResource(mgr manager.Manager, gvr schema.GroupVersionResource) (ctrlcache.Informer, error)
InformerForResource retrieves an informer for the given group version resource
func IsNamespaceInitializing ¶
IsNamespaceInitializing checks if the given namespace is initializing
func ListerFuncForResourceFunc ¶
func ListerFuncForResourceFunc(mgr manager.Manager) quota.ListerForResourceFunc
ListerFuncForResourceFunc knows how to provision a lister from an informer func. The lister returns errors until the informer has synced.
func StringsEqual ¶
StringsEqual checks if two string arrays are equal
Types ¶
type LockFactory ¶
LockFactory is the interface to retrieve named locks from
func NewDefaultLockFactory ¶
func NewDefaultLockFactory() LockFactory
NewDefaultLockFactory creates a new lock factory
Click to show internal directories.
Click to hide internal directories.